# mypy-boto3-mediastore

[![PyPI - mypy-boto3-mediastore](https://img.shields.io/pypi/v/mypy-boto3-mediastore.svg?color=blue)](https://pypi.org/project/mypy-boto3-mediastore)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-mediastore.svg?color=blue)](https://pypi.org/project/mypy-boto3-mediastore)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/master/logo.png)

Type annotations for
[boto3.MediaStore 1.16.30](https://boto3.amazonaws.com/v1/documentation/api/1.16.30/reference/services/mediastore.html#MediaStore) service
compatible with
[VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright)
and other tools.

Generated by [mypy-boto3-buider 4.1.3](https://github.com/vemel/mypy_boto3_builder).

More information can be found on [boto3-stubs](https://pypi.org/project/boto3-stubs/) page.

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/master/demo.gif)

- [mypy-boto3-mediastore](#mypy-boto3-mediastore)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Waiters annotations](#waiters-annotations)
    - [Service Resource annotations](#service-resource-annotations)
    - [Other resources annotations](#other-resources-annotations)
    - [Collections annotations](#collections-annotations)
    - [Typed dictionations](#typed-dictionations)

## How to install

Install `boto3-stubs` for `MediaStore` service.

```bash
python -m pip install boto3-stubs[mediastore]
```

## Usage

### VSCode

- Install [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[mediastore]` in your environment: `python -m pip install 'boto3-stubs[mediastore]'`

Both type checking and auto-complete should work for `MediaStore` service.
No explicit type annotations required, write your `boto3` code as usual.

### PyCharm

- Install `boto-stubs[mediastore]` in your environment: `python -m pip install 'boto3-stubs[mediastore]'`

Both type checking and auto-complete should work for `MediaStore` service.
No explicit type annotations required, write your `boto3` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed `boto3-stubs` submodules.

### Other IDEs

Not tested, but as long as your IDE support `mypy` or `pyright`, everything should work.

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[mediastore]` in your environment: `python -m pip install 'boto3-stubs[mediastore]'`
- Run `mypy` as usual

Type checking should work for `MediaStore` service.
No explicit type annotations required, write your `boto3` code as usual.

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[mediastore]` in your environment: `python -m pip install 'boto3-stubs[mediastore]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `MediaStore` service.
No explicit type annotations required, write your `boto3` code as usual.

## Explicit type annotations

### Client annotations

`MediaStoreClient` provides annotations for `boto3.client("mediastore")`.

```python
import boto3

from mypy_boto3_mediastore import MediaStoreClient

client: MediaStoreClient = boto3.client("mediastore")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: MediaStoreClient = session.client("mediastore")
```

### Paginators annotations

`mypy_boto3_mediastore.paginator` module contains type annotations for all paginators.

```python
from mypy_boto3_mediastore import MediaStoreClient
from mypy_boto3_mediastore.paginator import ListContainersPaginator

client: MediaStoreClient = boto3.client("mediastore")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
list_containers_paginator: ListContainersPaginator = client.get_paginator("list_containers")
```







### Typed dictionations

`mypy_boto3_mediastore.type_defs` module contains structures and shapes assembled
to typed dictionaries for additional type checking.

```python
from mypy_boto3_mediastore.type_defs import (
    ContainerTypeDef,
    CorsRuleTypeDef,
    CreateContainerOutputTypeDef,
    DescribeContainerOutputTypeDef,
    GetContainerPolicyOutputTypeDef,
    GetCorsPolicyOutputTypeDef,
    GetLifecyclePolicyOutputTypeDef,
    GetMetricPolicyOutputTypeDef,
    ListContainersOutputTypeDef,
    ListTagsForResourceOutputTypeDef,
    MetricPolicyRuleTypeDef,
    MetricPolicyTypeDef,
    PaginatorConfigTypeDef,
    ResponseMetadata,
    TagTypeDef,
)

def get_structure() -> ContainerTypeDef:
    return {
      ...
    }
```
